#!/bin/bash
#
# author           : M. Verwijmeren (aka Tibors) delphinidae@xs4all.nl
# maintainer       : P. Faasse (aka prfaasse) p.faase1@chello.nl
# latest update    : 01-aug-1008
# status           : stable
# update history   : 17-Jul-2007: updated to 0.12, added buildlog mechanism
#		     01-aug-2007: updated to 0.13
# dependencies     : none
DEPS=""
#   for creation   : 
# source location  : 
SRCURL="http://0pointer.de/lennart/projects/libdaemon/libdaemon-0.13.tar.gz"
# If this build script is called with the commandline parameter 'getsrc',
# then it will try to download the source files from the internet.

SOFTNAME=libdaemon
SOFTVERSION=0.13
ARCH=i486
CPU=i686
PACKAGEVERSION=54.1
PACKAGE=$SOFTNAME-$SOFTVERSION-$ARCH-$PACKAGEVERSION
SRCNAME=$SOFTNAME-$SOFTVERSION
SRCEXT=tar.gz

BUILDDIR=$(pwd)
DEST=$BUILDDIR/$PACKAGE
PREFIX=/usr
DESTSRC=$DEST$PREFIX/src/$SOFTNAME-$SOFTVERSION
DOC=$PREFIX/doc/$SOFTNAME-$SOFTVERSION
DESTDOC=$DEST$DOC

#
# for buildlog
#
(

rm -rfd $DEST
mkdir -p $DEST/install
mkdir -p $DESTSRC
mkdir -p $DESTDOC

cat << EOC > $DEST/install/slack-desc
         |-----handy-ruler------------------------------------------------------|
$SOFTNAME: libdaemon (a C library that eases the writing of UNIX daemons)
$SOFTNAME:
$SOFTNAME: * A wrapper around fork() which does the correct daemonization
$SOFTNAME:   procedure of a process.
$SOFTNAME: * A wrapper around syslog() for simpler and compatible log output to
$SOFTNAME:   Syslog or STDERR.
$SOFTNAME: * An API for writing PID files.
$SOFTNAME: * An API for serializing UNIX signals into a pipe for usage with
$SOFTNAME:   select() or poll().
$SOFTNAME: * An API for running subprocesses with STDOUT and STDERR redirected
$SOFTNAME:   to syslog.
EOC

if [ "$1" = "getsrc" ] ; then
	echo -e "\n-- download -----\n"
	wget $SRCURL
fi

echo -e "\n-- unpack -----\n"
rm -rfd $SRCNAME
tar xf $SRCNAME.$SRCEXT
cd $SRCNAME
chown -R root:root . 
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

echo -e "\n-- configure -----\n"
CFLAGS="-O2 -march=$ARCH -mtune=$CPU" \
	./configure \
	--prefix=$PREFIX \
	--disable-lynx || exit

echo -e "\n-- make -----\n"
make || exit

echo -e "\n-- install -----\n"
make install \
	DESTDIR=$DEST || exit

echo -e "\n-- manual copying -----\n"
cp LICENSE README doc/README.html doc/style.css $DESTDOC
cd $BUILDDIR
cp $0 $DESTSRC
chmod 0755 $DESTSRC/$0

cd $DEST
find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null
find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null
find . | xargs file | grep "current ar archive" | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null

echo -e "\n-- packaging -----\n"
cd $DEST
makepkg -l y -c n $BUILDDIR/$PACKAGE.tgz
cd $BUILDDIR
md5sum $PACKAGE.tgz > $PACKAGE.md5
cat << EOC > $PACKAGE.dep
$DEPS
EOC

#
# other end of the buildlog
#
) 2>&1 | tee libdaemon-log.txt
